@@ -7,13 +7,12 @@ specified.
 
 """
 import hashlib
+import importlib.util
 import io
 import os
 import re
 import sys
-import importlib.util
 import textwrap
-
 from os.path import join
 
 
@@ -85,7 +84,7 @@ API_FILES = [join('multiarray', 'alloc.c'),
              join('multiarray', 'stringdtype', 'static_string.c'),
              join('multiarray', 'strfuncs.c'),
              join('multiarray', 'usertypes.c'),
-             join('umath', 'dispatching.c'),
+             join('umath', 'dispatching.cpp'),
              join('umath', 'extobj.c'),
              join('umath', 'loops.c.src'),
              join('umath', 'reduction.c'),
@@ -129,7 +128,7 @@ class MinVersion:
 
 class StealRef:
     def __init__(self, arg):
-        self.arg = arg # counting from 1
+        self.arg = arg  # counting from 1
 
     def __str__(self):
         try:
@@ -154,10 +153,10 @@ class Function:
     def __str__(self):
         argstr = ', '.join([self._format_arg(*a) for a in self.args])
         if self.doc:
-            doccomment = '/* %s */\n' % self.doc
+            doccomment = f'/* {self.doc} */\n'
         else:
             doccomment = ''
-        return '%s%s %s(%s)' % (doccomment, self.return_type, self.name, argstr)
+        return f'{doccomment}{self.return_type} {self.name}({argstr})'
 
     def api_hash(self):
         m = hashlib.md5(usedforsecurity=False)
@@ -177,7 +176,7 @@ class ParseError(Exception):
         self.msg = msg
 
     def __str__(self):
-        return '%s:%s:%s' % (self.filename, self.lineno, self.msg)
+        return f'{self.filename}:{self.lineno}:{self.msg}'
 
 def skip_brackets(s, lbrac, rbrac):
     count = 0
@@ -188,12 +187,13 @@ def skip_brackets(s, lbrac, rbrac):
             count -= 1
         if count == 0:
             return i
-    raise ValueError("no match '%s' for '%s' (%r)" % (lbrac, rbrac, s))
+    raise ValueError(f"no match '{lbrac}' for '{rbrac}' ({s!r})")
 
 def split_arguments(argstr):
     arguments = []
     current_argument = []
     i = 0
+
     def finish_arg():
         if current_argument:
             argstr = ''.join(current_argument).strip()
@@ -212,8 +212,8 @@ def split_arguments(argstr):
             finish_arg()
         elif c == '(':
             p = skip_brackets(argstr[i:], '(', ')')
-            current_argument += argstr[i:i+p]
-            i += p-1
+            current_argument += argstr[i:i + p]
+            i += p - 1
         else:
             current_argument += c
         i += 1
@@ -283,7 +283,7 @@ def find_functions(filename, tag='API'):
                 if m:
                     function_name = m.group(1)
                 else:
-                    raise ParseError(filename, lineno+1,
+                    raise ParseError(filename, lineno + 1,
                                      'could not find function name')
                 function_args.append(line[m.end():])
                 state = STATE_ARGS
@@ -343,7 +343,7 @@ class TypeApi:
                                                self.index)
 
     def array_api_define(self):
-        return "        (void *) &%s" % self.name
+        return f"        (void *) &{self.name}"
 
     def internal_define(self):
         if self.internal_type is None:
@@ -375,12 +375,11 @@ class GlobalVarApi:
                                                         self.index)
 
     def array_api_define(self):
-        return "        (%s *) &%s" % (self.type, self.name)
+        return f"        ({self.type} *) &{self.name}"
 
     def internal_define(self):
-        astr = """\
-extern NPY_NO_EXPORT %(type)s %(name)s;
-""" % {'type': self.type, 'name': self.name}
+        astr = f"""extern NPY_NO_EXPORT {self.type} {self.name};
+"""
         return astr
 
 # Dummy to be able to consistently use *Api instances for all items in the
@@ -399,7 +398,7 @@ class BoolValuesApi:
                                               self.index)
 
     def array_api_define(self):
-        return "        (void *) &%s" % self.name
+        return f"        (void *) &{self.name}"
 
     def internal_define(self):
         astr = """\
@@ -447,20 +446,19 @@ class FunctionApi:
         return define
 
     def array_api_define(self):
-        return "        (void *) %s" % self.name
+        return f"        (void *) {self.name}"
 
     def internal_define(self):
         annstr = [str(a) for a in self.annotations]
         annstr = ' '.join(annstr)
-        astr = """\
-NPY_NO_EXPORT %s %s %s \\\n       (%s);""" % (annstr, self.return_type,
-                                              self.name,
-                                              self._argtypes_string())
+        astr = f"""NPY_NO_EXPORT {annstr} {self.return_type} {self.name} \\
+       ({self._argtypes_string()});"""
         return astr
 
 def order_dict(d):
     """Order dict by its values."""
     o = list(d.items())
+
     def _key(x):
         return x[1] + (x[0],)
     return sorted(o, key=_key)
@@ -496,7 +494,7 @@ def check_api_dict(d):
                 doubled[index] = [name]
         fmt = "Same index has been used twice in api definition: {}"
         val = ''.join(
-            '\n\tindex {} -> {}'.format(index, names)
+            f'\n\tindex {index} -> {names}'
             for index, names in doubled.items() if len(names) != 1
         )
         raise ValueError(fmt.format(val))
@@ -509,8 +507,7 @@ def check_api_dict(d):
                          f"{indexes.intersection(removed)}")
     if indexes.union(removed) != expected:
         diff = expected.symmetric_difference(indexes.union(removed))
-        msg = "There are some holes in the API indexing: " \
-              "(symmetric diff is %s)" % diff
+        msg = f"There are some holes in the API indexing: (symmetric diff is {diff})"
         raise ValueError(msg)
 
 def get_api_functions(tagname, api_dict):
@@ -537,6 +534,7 @@ def fullapi_hash(api_dicts):
         ''.join(a).encode('ascii'), usedforsecurity=False
     ).hexdigest()
 
+
 # To parse strings like 'hex = checksum' where hex is e.g. 0x1234567F and
 # checksum a 128 bits md5 checksum (hex format as well)
 VERRE = re.compile(r'(^0x[\da-f]{8})\s*=\s*([\da-f]{32})')
@@ -565,5 +563,6 @@ def main():
         print(hex(int(ah, 16)))
     print(hex(int(m.hexdigest()[:8], 16)))
 
+
 if __name__ == '__main__':
     main()
